

data ratpup;
  infile "rat_pup.dat" firstobs=2 dlm="09"X;
  input pup_id weight sex $	 litter litsize treatment $;
  if treatment = "High" then treat = 1;
  if treatment = "Low"  then treat = 2;
  if treatment = "Control" then treat = 3;
run;

proc format;
  value trtfmt 1 = "High"
               2 = "Low"
		       3 = "Control";
run;

title "Summary statistics for weight by treatment and sex";
proc means data=ratpup maxdec=2;
  class treat sex;
  var weight;
  format treat trtfmt.;
run;

proc sort data=ratpup;
  by treat sex;
run;

title "Figure 3.1";
proc boxplot data=ratpup;
  plot weight * sex (treat) /
       boxstyle=schematic cboxes=black idsymbol=circle 
       blockpos=3 
       font=swissb height=2;
  format treat trtfmt.;
run;

proc sort data=ratpup;
  by litsize litter;
run;

data ratpup2;
  set ratpup;
  by litsize litter;
  if first.litter then ranklit+1;
  label ranklit="New Litter ID (Ordered by Size)";
run;

proc sort data=ratpup2;
  by treat sex ranklit;
run;

/* Fig.3.2: Boxplots by litsize for each level of treat and sex*/

title;
goptions fby=swissb hby=2;
proc boxplot data=ratpup2;
    plot weight * ranklit /
       boxstyle=schematic cboxes=black 
       blockpos=3 
       idsymbol=circle 
       vaxis=(3 to 9 by 1) height=3
	 font=swissb nlegend;
    by treat sex;
format treat trtfmt.;
run;

/* Model Fitting */

title "Model 3.1";
proc mixed data=ratpup order=internal covtest ;
  class treat sex litter ;
  model weight =  treat sex litsize treat*sex / 
                  solution ddfm = sat ;
  random int / subject=litter ;
  format treat trtfmt. ;
run ;

title "Model 3.1A";
proc mixed data=ratpup order=internal covtest ;
  class treat sex litter ;
  model weight =  treat sex treat*sex litsize / 
                  solution ddfm = sat ;
  format treat trtfmt. ;
run;

title "P-value for Hypothesis 3.1: Simple syntax";
data _null_; 
    lrtstat = 490.5 - 401.1;
    df = 1; 
    pvalue = 0.5*(1 - probchi(lrtstat,df));
    format pvalue 10.8;  
    put lrtstat= df= pvalue=; 
run;

title "Model 3.2A";
proc mixed data=ratpup order=internal covtest;
  class treat litter sex;
  model weight = treat sex treat*sex litsize /
                 solution ddfm=sat  ;
  random int / subject=litter;
  repeated / group=treat;
  format treat trtfmt.;
run;

title "P-value for Hypothesis 3.2";
data _null_;
  lrtstat = 401.1-359.9;
  df=2;
  pvalue = 1 - probchi(lrtstat,df);
  format pvalue 10.8;
  put lrtstat=df=pvalue=;
run;

title "RATPUP3 dataset";
data ratpup3;
  set ratpup2;
  if treatment in ("High", "Low") then TRTGRP = 1;
  if treatment = "Control" then TRTGRP = 2;
run;

proc format;
  value tgrpfmt 1="High/Low"
                2="Control";
run;

title "Model 3.2B";
proc mixed data=ratpup3 order=internal covtest; 
  class treat litter sex trtgrp;
  model weight = treat sex treat*sex litsize /
                 solution ddfm=sat ;
  random int / subject=litter ;
  repeated / group=trtgrp;
  format treat trtfmt. trtgrp tgrpfmt.;
run ;

title "P-value for Hypothesis 3.3";
data _null_;
lrtstat = 361.1-359.9;
df = 1;
pvalue = 1-probchi(lrtstat, df);
format pvalue 10.8;
put lrtstat = df = pvalue =;
run;

title "Model 3.3 using ML";
proc mixed data=ratpup3 order=internal method=ml;
  class treat litter sex trtgrp;
  model weight = treat sex litsize /solution ddfm=sat  ;
  random int / subject=litter;
  repeated / group=trtgrp;
  format treat trtfmt.;
run ;

title "Model 3.3A using ML";
proc mixed data=ratpup3 order=internal method=ml;
  class treat litter sex trtgrp;
  model weight = sex litsize /solution ddfm=sat ;
  random int / subject=litter;
  repeated / group=trtgrp;
  format treat trtfmt.;
run ;

title "P-value for Hypothesis 3.6";
data _null_;
  lrtstat = 356.5-337.8;
  df=2;
  pvalue = 1 - probchi(lrtstat,df);
  format pvalue 10.8;
  put lrtstat=df=pvalue=;
run;

/*Refit Model 3.3 using REML estimation*/
proc sort data=ratpup3;
  by pup_id;
run;

goptions reset=all;

ods rtf file="ratpup_diagnostics.rtf";
ods graphics on ;

title "Model 3.3 using REML, Model diagnostics";
proc mixed data=ratpup3 order=internal boxplot covtest ;
  class treat litter sex trtgrp;
  model weight = treat sex litsize / solution ddfm=sat 
  residual outpred = pdat1 outpredm = pdat2
                  influence(iter=5 effect=litter est) ;
  id pup_id litter treatment trtgrp ranklit litsize;
  random int / subject=litter solution v=3 vcorr=3 ;
  repeated / group=trtgrp ;
  lsmeans treat / adjust=tukey ;
  format treat trtfmt. trtgrp tgrpfmt.;
run ;

ods graphics off;
ods rtf close;


/* diagnostics */

proc sort data=pdat1;
 by trtgrp;
run;

/*Distribution of conditional raw residuals by treatment group*/

title;
goptions fby=swissb hby=2;
proc univariate data=pdat1 normal;
  format trtgrp tgrpfmt.;
  by trtgrp;
  var resid;
  histogram;
  qqplot / normal(mu=est sigma=est);
run;

/*Plot of conditional raw residuals vs. predicted values*/
proc gplot data=pdat1;
  format trtgrp tgrpfmt.;
  by trtgrp;
  plot resid*pred / haxis=axis1;
  axis1 order=4 to 8 by 1;
  symbol1 color=black value=dot height=1;
run;
quit;













